export type UseAsyncOnResultProps<ResultSchema> = {
    result: ResultSchema;
};
export type UseAsyncOnErrorProps<ExecPayload> = {
    error: Error | string;
    fnProps: ExecPayload;
};
export type UseAsyncOnLoadingProps = {
    loading: boolean;
};
export type UseAsyncProps<ExecPayload = any, ResultSchema = any> = {
    fn: (props: ExecPayload) => Promise<ResultSchema>;
    autoExec?: boolean;
    defaultData?: ResultSchema;
    defaultPayload?: ExecPayload;
    additionalPayload?: ExecPayload;
    onResult?: (props: UseAsyncOnResultProps<ResultSchema>) => any;
    onError?: (props: UseAsyncOnErrorProps<ExecPayload>) => any;
    onLoading?: (props: UseAsyncOnLoadingProps) => any;
};
export type UseAsyncReturn<ExecPayload = any, ResultSchema = any> = {
    loading: boolean;
    error: Error | string | null;
    result: ResultSchema;
    exec: (payload?: ExecPayload | undefined) => Promise<{
        result: ResultSchema | undefined;
        error: Error | undefined;
    } | null>;
    publicErrorMessage: string | null;
};
/**
 * @example
 * const promise = useAsync({
 * fn
 * })
 */
export default function useAsync<ExecPayload, ResultSchema>({ fn, autoExec, defaultData, defaultPayload, additionalPayload, onResult, onError, onLoading, }: UseAsyncProps<ExecPayload, ResultSchema>): UseAsyncReturn<ExecPayload, ResultSchema>;
